INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', NULL, 1230796800, 38832, 15, 0);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', NULL, 1230796800, 77664, 22, 2718);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', NULL, 1230796800, 126264, 26, 5825);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', NULL, 1230796800, 126264, 29, 9613);

INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'BC', 1230796800, 35716, 5.06, 0);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'BC', 1230796800, 71433, 7.7, 943);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'BC', 1230796800, 82014, 10.5, 2943);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'BC', 1230796800, 99588, 12.29, 4411);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'BC', 1230796800, 99588, 14.7, 6811);

INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'MB', 1230796800, 31000, 10.8, 0);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'MB', 1230796800, 67000, 12.75, 605);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'MB', 1230796800, 67000, 17.4, 3720);

INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NB', 1230796800, 35707, 10.12, 0);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NB', 1230796800, 71415, 15.48, 1914);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NB', 1230796800, 116105, 16.8, 2857);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NB', 1230796800, 116105, 17.95, 4192);

INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NL', 1230796800, 31061, 7.7, 0);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NL', 1230796800, 62121, 12.8, 1584);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NL', 1230796800, 62121, 15.5, 3261);

INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NT', 1230796800, 36885, 5.9, 0);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NT', 1230796800, 73772, 8.6, 996);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NT', 1230796800, 119936, 12.2, 3652);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NT', 1230796800, 119936, 14.05, 5871);

INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NU', 1230796800, 38832, 4.0, 0);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NU', 1230796800, 77664, 7.0, 1165);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NU', 1230796800, 126264, 9.0, 2718);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NU', 1230796800, 126264, 11.5, 5875);

INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'ON', 1230796800, 36848, 6.05, 0);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'ON', 1230796800, 73698, 9.15, 1142);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'ON', 1230796800, 73698, 11.16, 2624);

INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'SK', 1230796800, 40113, 11, 0);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'SK', 1230796800, 114610, 13, 802);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'SK', 1230796800, 114610, 15, 3094);

INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'YT', 1230796800, 38832, 7.04, 0);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'YT', 1230796800, 77664, 9.68, 1025);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'YT', 1230796800, 126264, 11.44, 2392);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'YT', 1230796800, 126264, 12.76, 4059);


INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', NULL, NULL, 1230796800, 10, 2650, 0, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', NULL, NULL, 1230796800, 10, 10400, 10, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', NULL, NULL, 1230796800, 10, 35400, 15, 775);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', NULL, NULL, 1230796800, 10, 84300, 25, 4525);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', NULL, NULL, 1230796800, 10, 173600, 28, 16750);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', NULL, NULL, 1230796800, 10, 375000, 33, 41754);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', NULL, NULL, 1230796800, 10, 375000, 35, 108216);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', NULL, NULL, 1230796800, 20, 8000, 0, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', NULL, NULL, 1230796800, 20, 23950, 10, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', NULL, NULL, 1230796800, 20, 75650, 15, 1595);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', NULL, NULL, 1230796800, 20, 144800, 25, 9350);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', NULL, NULL, 1230796800, 20, 216600, 28, 26637.50);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', NULL, NULL, 1230796800, 20, 380700, 33, 46741.50);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', NULL, NULL, 1230796800, 20, 380700, 35, 100894.50);

INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'NC', NULL, 1230796800, 10, 12750, 6, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'NC', NULL, 1230796800, 10, 60000, 7, 127.50);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'NC', NULL, 1230796800, 10, 60000, 7.75, 577.50);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'NC', NULL, 1230796800, 20, 10625, 6, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'NC', NULL, 1230796800, 20, 50000, 7, 106.25);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'NC', NULL, 1230796800, 20, 50000, 7.75, 481.25);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'NC', NULL, 1230796800, 30, 17000, 6, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'NC', NULL, 1230796800, 30, 80000, 7, 170);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'NC', NULL, 1230796800, 30, 80000, 7.75, 770);

INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'ND', NULL, 1230796800, 10, 3800, 0, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'ND', NULL, 1230796800, 10, 36000, 2.10, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'ND', NULL, 1230796800, 10, 76000, 3.92, 676.20);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'ND', NULL, 1230796800, 10, 173000, 4.34, 2244.20);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'ND', NULL, 1230796800, 10, 375000, 5.04, 6454.00);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'ND', NULL, 1230796800, 10, 375000, 5.54, 16634.80);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'ND', NULL, 1230796800, 20, 9300, 0, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'ND', NULL, 1230796800, 20, 64000, 2.10, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'ND', NULL, 1230796800, 20, 122000, 3.92, 1148.70);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'ND', NULL, 1230796800, 20, 217000, 4.34, 3422.30);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'ND', NULL, 1230796800, 20, 380000, 5.04, 7545.30);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'ND', NULL, 1230796800, 20, 380000, 5.54, 15760.50);

INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'MN', NULL, 1230796800, 10, 2050, 0, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'MN', NULL, 1230796800, 10, 24780, 5.35, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'MN', NULL, 1230796800, 10, 76700, 7.05, 1216.06);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'MN', NULL, 1230796800, 10, 76700, 7.85, 4876.42);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'MN', NULL, 1230796800, 20, 7750, 0, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'MN', NULL, 1230796800, 20, 40970, 5.35, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'MN', NULL, 1230796800, 20, 139720, 7.05, 1777.27);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'MN', NULL, 1230796800, 20, 139720, 7.85, 8739.15);

INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'OK', NULL, 1230796800, 10, 4250, 0, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'OK', NULL, 1230796800, 10, 5250, 0.5, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'OK', NULL, 1230796800, 10, 6750, 1.0, 5);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'OK', NULL, 1230796800, 10, 8000, 2.0, 20);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'OK', NULL, 1230796800, 10, 9150, 3.0, 45);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'OK', NULL, 1230796800, 10, 11450, 4.0, 79.50);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'OK', NULL, 1230796800, 10, 12950, 5.0, 171.50);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'OK', NULL, 1230796800, 10, 12950, 5.5, 246.50);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'OK', NULL, 1230796800, 20, 8500, 0, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'OK', NULL, 1230796800, 20, 10500, 0.5, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'OK', NULL, 1230796800, 20, 13500, 1.0, 10);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'OK', NULL, 1230796800, 20, 16000, 2.0, 40);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'OK', NULL, 1230796800, 20, 18300, 3.0, 90);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'OK', NULL, 1230796800, 20, 20700, 4.0, 159);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'OK', NULL, 1230796800, 20, 23500, 5.0, 255);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'OK', NULL, 1230796800, 20, 23500, 5.5, 395);

INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'VT', NULL, 1230796800, 10, 2650, 0, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'VT', NULL, 1230796800, 10, 35400, 3.6, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'VT', NULL, 1230796800, 10, 84300, 7.2, 1179.00);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'VT', NULL, 1230796800, 10, 173600, 8.5, 4699.80);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'VT', NULL, 1230796800, 10, 375000, 9.0, 12290.30);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'VT', NULL, 1230796800, 10, 375000, 9.5, 30416.30);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'VT', NULL, 1230796800, 20, 8000, 0, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'VT', NULL, 1230796800, 20, 63100, 3.6, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'VT', NULL, 1230796800, 20, 144800, 7.2, 1983.60);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'VT', NULL, 1230796800, 20, 216600, 8.5, 7866.00);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'VT', NULL, 1230796800, 20, 380700, 9.0, 13969.00);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'VT', NULL, 1230796800, 20, 380700, 9.5, 28738.00);

INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'ME', NULL, 1230796800, 10, 2850, 0, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'ME', NULL, 1230796800, 10, 7900, 2.0, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'ME', NULL, 1230796800, 10, 12900, 4.5, 101);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'ME', NULL, 1230796800, 10, 23000, 7.0, 326);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'ME', NULL, 1230796800, 10, 23000, 8.5, 1033);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'ME', NULL, 1230796800, 20, 6650, 0, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'ME', NULL, 1230796800, 20, 16800, 2.0, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'ME', NULL, 1230796800, 20, 26800, 4.5, 203);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'ME', NULL, 1230796800, 20, 47000, 7.0, 653);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'ME', NULL, 1230796800, 20, 47000, 8.5, 2067);

INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'DC', NULL, 1230796800, 10, 4200, 0, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'DC', NULL, 1230796800, 10, 10000, 4.0, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'DC', NULL, 1230796800, 10, 40000, 6.0, 232);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'DC', NULL, 1230796800, 10, 40000, 8.5, 2032);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'DC', NULL, 1230796800, 20, 4200, 0, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'DC', NULL, 1230796800, 20, 10000, 4.0, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'DC', NULL, 1230796800, 20, 40000, 6.0, 232);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'DC', NULL, 1230796800, 20, 40000, 8.5, 2032);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'DC', NULL, 1230796800, 30, 2100, 0, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'DC', NULL, 1230796800, 30, 10000, 4.0, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'DC', NULL, 1230796800, 30, 40000, 6.0, 316);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'DC', NULL, 1230796800, 30, 40000, 8.5, 2116);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'DC', NULL, 1230796800, 40, 4200, 0, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'DC', NULL, 1230796800, 40, 10000, 4.0, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'DC', NULL, 1230796800, 40, 40000, 6.0, 232);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'DC', NULL, 1230796800, 40, 40000, 8.5, 2032);

INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'RI', NULL, 1230796800, 10, 2650, 0, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'RI', NULL, 1230796800, 10, 36000, 3.75, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'RI', NULL, 1230796800, 10, 78700, 7.0, 1250.63);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'RI', NULL, 1230796800, 10, 173600, 7.75, 4239.63);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'RI', NULL, 1230796800, 10, 374950, 9.0, 11594.38);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'RI', NULL, 1230796800, 10, 374950, 9.9, 29715.88);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'RI', NULL, 1230796800, 20, 6450, 0, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'RI', NULL, 1230796800, 20, 62600, 3.75, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'RI', NULL, 1230796800, 20, 133200, 7.0, 2105.63);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'RI', NULL, 1230796800, 20, 214700, 7.75, 7047.63);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'RI', NULL, 1230796800, 20, 378800, 9.0, 13363.88);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'RI', NULL, 1230796800, 20, 378800, 9.9, 28132.88);

INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'OH', NULL, 1230796800, 0, 5000, 0.638, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'OH', NULL, 1230796800, 0, 10000, 1.276, 31.90);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'OH', NULL, 1230796800, 0, 15000, 2.552, 95.70);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'OH', NULL, 1230796800, 0, 20000, 3.190, 223.30);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'OH', NULL, 1230796800, 0, 40000, 3.828, 382.80);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'OH', NULL, 1230796800, 0, 80000, 4.466, 1148.40);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'OH', NULL, 1230796800, 0, 100000, 5.103, 2934.80);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'OH', NULL, 1230796800, 0, 100000, 6.379, 3955.40);

INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'CA', NULL, 1230796800, 10, 7168, 1.0, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'CA', NULL, 1230796800, 10, 16994, 2.0, 71.68);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'CA', NULL, 1230796800, 10, 26821, 4.0, 268.20);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'CA', NULL, 1230796800, 10, 37233, 6.0, 661.28);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'CA', NULL, 1230796800, 10, 47055, 8.0, 1286.00);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'CA', NULL, 1230796800, 10, 1000000, 9.3, 2071.76);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'CA', NULL, 1230796800, 10, 1000000, 10.3, 90695.65);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'CA', NULL, 1230796800, 20, 7168, 1.0, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'CA', NULL, 1230796800, 20, 16994, 2.0, 71.68);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'CA', NULL, 1230796800, 20, 26821, 4.0, 268.20);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'CA', NULL, 1230796800, 20, 37233, 6.0, 661.28);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'CA', NULL, 1230796800, 20, 47055, 8.0, 1286.00);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'CA', NULL, 1230796800, 20, 1000000, 9.3, 2071.76);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'CA', NULL, 1230796800, 20, 1000000, 10.3, 90695.65);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'CA', NULL, 1230796800, 30, 14336, 1.0, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'CA', NULL, 1230796800, 30, 33988, 2.0, 143.36);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'CA', NULL, 1230796800, 30, 53642, 4.0, 536.40);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'CA', NULL, 1230796800, 30, 74466, 6.0, 1322.56);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'CA', NULL, 1230796800, 30, 94110, 8.0, 2572.00);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'CA', NULL, 1230796800, 30, 1000000, 9.3, 4143.52);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'CA', NULL, 1230796800, 30, 1000000, 10.3, 88391.29);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'CA', NULL, 1230796800, 40, 14345, 1.0, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'CA', NULL, 1230796800, 40, 33989, 2.0, 143.45);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'CA', NULL, 1230796800, 40, 43814, 4.0, 536.33);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'CA', NULL, 1230796800, 40, 54225, 6.0, 929.33);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'CA', NULL, 1230796800, 40, 64050, 8.0, 1553.99);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'CA', NULL, 1230796800, 40, 1000000, 9.3, 2339.99);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'CA', NULL, 1230796800, 40, 1000000, 10.3, 89383.34);

INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'NM', NULL, 1230796800, 10, 2050, 0, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'NM', NULL, 1230796800, 10, 7550, 1.7, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'NM', NULL, 1230796800, 10, 13050, 3.2, 93.50);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'NM', NULL, 1230796800, 10, 18050, 4.7, 269.50);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'NM', NULL, 1230796800, 10, 18050, 4.9, 504.50);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'NM', NULL, 1230796800, 20, 7750, 0, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'NM', NULL, 1230796800, 20, 15750, 1.7, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'NM', NULL, 1230796800, 20, 23750, 3.2, 136);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'NM', NULL, 1230796800, 20, 31750, 4.7, 392);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'NM', NULL, 1230796800, 20, 31750, 4.9, 768);

INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'ID', NULL, 1230796800, 10, 1950, 0, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'ID', NULL, 1230796800, 10, 3222, 1.6, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'ID', NULL, 1230796800, 10, 4494, 3.6, 20);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'ID', NULL, 1230796800, 10, 5766, 4.1, 66);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'ID', NULL, 1230796800, 10, 7038, 5.1, 118);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'ID', NULL, 1230796800, 10, 8310, 6.1, 183);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'ID', NULL, 1230796800, 10, 11490, 7.1, 261);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'ID', NULL, 1230796800, 10, 27391, 7.4, 487);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'ID', NULL, 1230796800, 10, 27391, 7.8, 1664);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'ID', NULL, 1230796800, 20, 7400, 0, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'ID', NULL, 1230796800, 20, 9944, 1.6, 0);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'ID', NULL, 1230796800, 20, 12488, 3.6, 41);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'ID', NULL, 1230796800, 20, 15032, 4.1, 133);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'ID', NULL, 1230796800, 20, 17576, 5.1, 237);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'ID', NULL, 1230796800, 20, 20120, 6.1, 367);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'ID', NULL, 1230796800, 20, 26480, 7.1, 522);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'ID', NULL, 1230796800, 20, 58282, 7.4, 974);
INSERT INTO income_tax_rate_us VALUES (DEFAULT, 'US', 'ID', NULL, 1230796800, 20, 58282, 7.8, 3327);
